/*cd *//*Set the path to your directory*/

cd "C:/Users/scheve/Dropbox/SP-TEC/ReplicationArchive"

log using "Scheve_Stasavage_TaxingtheRich_2016_replication.smcl", replace

/************************************************************************************
*	Taxing the Rich: A History of Fiscal Fairness in the United States and Europe	*
*	By Kenneth Scheve and David Stasavage											*
*	2016, Princeton University Press												*
*																					*
*	This file conducts replication analysis for the materials presented throughout	*
*	Taxing the Rich and the supplementary Online Appendix.							*
************************************************************************************/

# delimit;
clear;
set more off;
quietly;

/**************
Chapter 1:
Why Might Governments Tax the Rich?
**************/

/**
Make Figure 1.1
**/

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
xtset ccode year;

collapse  (mean) top_incrate_n topitaxrate2 if independence == 1 & year>=1800 & year<=2013, by(year);
summarize;

/**Figure 1.1. Average Top Rates of Income and Inheritance Taxation, 1800-2013 (page 10)**/
twoway (line top_incrate_n year, lwidth(medthick) lpattern(solid)) (line topitaxrate2 year, lwidth(medthick) lpattern(shortdash)), ytitle(Percent) xtitle(Year) title(Average Top Rates of Income and Inheritance Taxation) subtitle(1800-2013) graphregion(fcolor(white)) legend(row(1) order(1 2) lab(1 "Income Tax")  lab(2 "Inheritance Tax"));
graph save figure_1_1,replace;

clear;

/**************
Chapter 2:
Treating Citizens as Equals
**************/

use "Scheve_Stasavage_TaxingtheRich_2016_LSSsurveyexperiment.dta", replace;

/*Response Frequencies (unweighted)*/
tab taxincrease_dfit1;
tab taxincrease_dfit2;
tab taxincrease_dfit3;
tab taxincrease_dfit4;
/*Proportion of times that respondents chose Plan A (unweighted)*/
disp (190+193+196+199)/(500*4);

/*Response Frequencies (weighted)*/
tab taxincrease_dfit1 [aweight=weight];
tab taxincrease_dfit2 [aweight=weight];
tab taxincrease_dfit3 [aweight=weight];
tab taxincrease_dfit4 [aweight=weight];
/*Proportion of times that respondents chose Plan A (weighted)*/
disp (184.758+212.603+188.647+195.773)/(500*4); 

/*Response Explanation Frequencies (unweighted and including those who indicated multiple reasons)*/
tab Reasons_DefExp;
/*Proportion of respondents that made fairness claims (unweighted and including those who indicated multiple reasons)*/
disp (62+77+15+65)/427; 

/*Response Explanation Frequencies (unweighted and excluding those who indicated multiple reasons)*/
tab Reasons_DefExp if Reasons_DefExp~=9;
/*Proportion of respondents that made fairness claims (unweighted and excluding those who indicated multiple reasons)*/
disp (62+77+15+65)/411; 

/*Response Explanation Frequencies (weighted and excluding those who indicated multiple reasons)*/
tab Reasons_DefExp [aweight=weight] if Reasons_DefExp~=9;
/*Proportion of respondents that made fairness claims (weighted and excluding those who indicated multiple reasons)*/
disp (52.001+67.734+12.429+78.740)/411; 

/*Respondents by income group (unweighted)*/
tab personalinc_blw25k;
tab personalinc_btw25k_200k;
tab personalinc_greater_200k;

/*Respondents by income group (weighted)*/
tab personalinc_blw25k [aweight=weight];
tab personalinc_btw25k_200k [aweight=weight];
tab personalinc_greater_200k [aweight=weight];

/*Response Frequencies by Income Group (unweighted)*/
tab taxincrease_dfit1 personalinc_blw25k;
tab taxincrease_dfit2 personalinc_blw25k;
tab taxincrease_dfit3 personalinc_blw25k;
tab taxincrease_dfit4 personalinc_blw25k;
/*Proportion of times that respondents made a congruent choice (unweighted)*/
disp (121+124+126+125+145+145+144+140)/(500*4);

/*Response Frequencies by Income Group (weighted)*/
tab taxincrease_dfit1 personalinc_blw25k [aweight=weight];
tab taxincrease_dfit2 personalinc_blw25k [aweight=weight];
tab taxincrease_dfit3 personalinc_blw25k [aweight=weight];
tab taxincrease_dfit4 personalinc_blw25k [aweight=weight];
/*Proportion of times that respondents made a congruent choice (weighted)*/
disp (111.209+128.560+116.389+115.865+163.331+152.837+164.621+156.971)/(500*4);

gen congruent_dfit4=.;
replace congruent_dfit4=1 if taxincrease_dfit4==1 & personalinc_blw25k==1;
replace congruent_dfit4=1 if taxincrease_dfit4==0 & personalinc_blw25k==0;
replace congruent_dfit4=0 if taxincrease_dfit4==0 & personalinc_blw25k==1;
replace congruent_dfit4=0 if taxincrease_dfit4==1 & personalinc_blw25k==0;

/*Congruent Choices for Fourth Pair (unweighted)*/
tab congruent_dfit4;
/*Congruent Choices for Fourth Pair (weighted)*/
tab congruent_dfit4 [aweight=weight];

gen fairnessreasons=.;
replace fairnessreasons=1 if Reasons_DefExp==2|Reasons_DefExp==3|Reasons_DefExp==4|Reasons_DefExp==7;
replace fairnessreasons=0 if Reasons_DefExp==1|Reasons_DefExp==5|Reasons_DefExp==6|Reasons_DefExp==8;

/*Response Explanation Frequencies by Choice Congruence (unweighted)*/
tab fairnessreasons if congruent_dfit4==1;
tab fairnessreasons if congruent_dfit4==0;

/*Response Explanation Frequencies by Choice Congruence (weighted)*/
tab fairnessreasons if congruent_dfit4==1 [aweight=weight];
tab fairnessreasons if congruent_dfit4==0 [aweight=weight];

/*Response Explanation Frequencies by Income Group for Respondents who made Incongruent Choices (unweighted)*/
tab fairnessreasons if congruent_dfit4==0 & personalinc_blw25k==1;
tab fairnessreasons if congruent_dfit4==0 & personalinc_blw25k==0;

/*Response Explanation Frequencies by Income Group for Respondents who made Incongruent Choices (weighted)*/
tab fairnessreasons if congruent_dfit4==0 & personalinc_blw25k==1 [aweight=weight];
tab fairnessreasons if congruent_dfit4==0 & personalinc_blw25k==0 [aweight=weight];

clear;

/**************
Chapter 3:
The Income Tax over Two Centuries
**************/

/**
Make Figure 3.1
**/

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
xtset ccode year;

preserve;

collapse  (mean) top_incrate_n if independence==1 & year>=1800 & year<=2013, by(year);

/**Figure 3.1. Average Top Rates of Income Taxation, 1800-2013 (page 56) **/
twoway (line top_incrate_n year, lwidth(medthick) lpattern(solid)), ytitle(Percent) xtitle(Year) title(Average Top Rate of Income Taxation) subtitle(1800-2013) graphregion(fcolor(white)) legend(off);
graph save figure_3_01,replace;

restore;

/**
Make Figure 3.2
**/

/**Figure 3.2. Top Rates of Income Taxation, Selected Years (page 57)**/
twoway scatter top_incrate_n year if year==1900|year==1925|year==1950|year==1975|year==2000|year==2013, msymbol(i) mlabel(country) mlabposition(0) mlabsize(vsmall)  ytitle(Percent) xtitle(Year) graphregion(fcolor(white))  legend(off) xscale(r(1890 2025)) xlabel(1900 1925 1950 1975 2000 2013) title(Top Rate of Income Taxation) subtitle(Selected Years);
graph save figure_3_02,replace;

clear;

/**
Make Figure 3.3
**/

use Scheve_Stasavage_TaxingtheRich_2016_schedules.dta, replace;

line taxrate multiples_stand if year==1925 & country == "France", lcolor(green)  lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "France",  lcolor(cranberry)  lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "France",  lcolor(blue)  lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "France",  lcolor(orange)  lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "France", lcolor(lavender) lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("France, 1925-2010", size(medium)) legend(label(1 "1925") label(2 "1950") label(3 "1975") label(4 "2000") label(5 "2010"))  legend(rows(2)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_france);
line taxrate multiples_stand if year==1925 & country == "Germany", lcolor(green)  lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "Germany",  lcolor(cranberry)  lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "Germany",  lcolor(blue) lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "Germany",  lcolor(orange)   lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "Germany", lcolor(lavender) lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("Germany, 1925-2010", size(medium)) legend(label(1 "1925") label(2 "1950") label(3 "1975") label(4 "2000") label(5 "2010")) legend(rows(2)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_germany);
line taxrate multiples_stand if year==1900 & country == "New Zealand", lcolor(pink)  lpattern(longdash_dot) || line taxrate multiples_stand if year==1925 & country == "New Zealand", lcolor(green) lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "New Zealand",  lcolor(cranberry) lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "New Zealand",  lcolor(blue)  lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "New Zealand",  lcolor(orange) lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "New Zealand", lcolor(lavender)  lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("New Zealand, 1900-2010", size(medium)) legend(label(1 "1900") label(2 "1925") label(3 "1950") label(4 "1975") label(5 "2000") label(6 "2010"))  legend(rows(2)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_nz);
line taxrate multiples_stand if year==1875 & country == "Sweden",  lcolor(gray)  lpattern(shortdash_dot) || line taxrate multiples_stand if year==1900 & country == "Sweden", lcolor(pink)  lpattern(longdash_dot) || line taxrate multiples_stand if year==1925 & country == "Sweden", lcolor(green) lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "Sweden",  lcolor(cranberry) lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "Sweden",  lcolor(blue)  lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "Sweden",  lcolor(orange) lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "Sweden", lcolor(lavender) lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("Sweden, 1875-2010", size(medium)) legend(label (1 "1875") label(2 "1900") label(3 "1925") label(4 "1950") label(5 "1975") label(6 "2000") label(7 "2010")) legend(rows(3)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_sweden);
line taxrate multiples_stand if year==1875 & country == "United Kingdom", lcolor(gray) lpattern(shortdash_dot) || line taxrate multiples_stand if year==1900 & country == "United Kingdom",  lcolor(pink) lpattern(longdash_dot) || line taxrate multiples_stand if year==1925 & country == "United Kingdom",  lcolor(green)  lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "United Kingdom",  lcolor(cranberry)  lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "United Kingdom",  lcolor(blue)   lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "United Kingdom",  lcolor(orange) lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "United Kingdom", lcolor(lavender) lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("UK, 1875-2010", size(medium)) legend(label (1 "1875") label(2 "1900") label(3 "1925") label(4 "1950") label(5 "1975") label(6 "2000") label(7 "2010"))  legend(rows(3)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_uk);
line taxrate multiples_stand if year==1925 & country == "United States",lcolor(green) lpattern(solid) || line taxrate multiples_stand if year==1950 & country == "United States",  lcolor(cranberry) lpattern(dash) || line taxrate multiples_stand if year==1975 & country == "United States",  lcolor(blue)  lpattern(dot) ||  line taxrate multiples_stand if year==2000 & country == "United States",  lcolor(orange) lpattern(shortdash) ||  line taxrate multiples_stand if year==2010 & country == "United States", lcolor(lavender)  lpattern(longdash) ||, ylabel(0 0(10)100, gmax angle(horizontal) nogrid) xlabel(1 "0.5" 2 "1" 3 "1.5" 4 "2" 5 "4" 6 "100") note(" ", span position(6) size(large) lcolor(white)) ytitle("Marginal rate (%)", size(medium) margin(0 4 0 0)) xtitle("Multiples of GDP per capita") title("USA, 1925-2010", size(medium)) legend(label(1 "1925") label(2 "1950") label(3 "1975") label(4 "2000") label(5 "2010"))  legend(rows(2)) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_03_us);

/**Figure 3.3. Full Schedules of Statutory Income Tax Rates (page 59)**/
gr combine figure_3_03_france figure_3_03_germany figure_3_03_nz figure_3_03_sweden figure_3_03_uk figure_3_03_us, title("Full schedules of statutory rates")  plotregion(fcolor(white)) graphregion(fcolor(white))  iscale(.55)   ycommon;
graph save figure_3_03,replace;

graph drop _all;
clear;

/**
Make Figure 3.4
**/

use "Scheve_Stasavage_TaxingtheRich_2016_annual.dta", replace;
xtset ccode year;
preserve;
keep country ccode year top_incrate_n top_incrate_nl effective_p99_99 irs_soi_top1;

gen top_statutory2 = .;
replace top_statutory2 = top_incrate_nl if country == "Canada"; 
replace top_statutory2 = top_incrate_n if country == "France";
replace top_statutory2 = top_incrate_n if country == "Netherlands"; 
replace top_statutory2 = top_incrate_nl if country == "Sweden"; 
replace top_statutory2 = top_incrate_n if country == "United Kingdom";
replace top_statutory2 = top_incrate_n if country == "United States";

drop if country=="Canada" & (year<1918 | year>2000);
drop if country=="France" & (year<1915 | year>1998);
drop if country=="Netherlands" & (year<1946 | year >1999);
drop if country=="Sweden" & (year<1903 | year>1990);
drop if country=="United States" & (year<1916 | year >1995);
drop if country=="United Kingdom" & (year<1936 | year>2000);

cor top_statutory2 effective_p99_99 if country == "Canada";
cor top_statutory2 effective_p99_99 if country == "France";
cor top_statutory2 effective_p99_99 if country == "Netherlands";
cor top_statutory2 effective_p99_99 if country == "Sweden";
cor top_statutory2 effective_p99_99 if country == "United Kingdom";
cor top_statutory2 irs_soi_top1 if country == "United States";

twoway 	(tsline top_statutory2, lpattern(solid)) (tsline effective_p99_99,  lpattern(dash)) if country=="Canada" & year >= 1918 & year <= 2000, title("Top marginal rates in Canada",  size(medium)) subtitle("{&rho} = 0.704") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_canada);
twoway 	(tsline top_statutory2, lpattern(solid)) (tsline effective_p99_99,  lpattern(dash)) if country=="France", title("Top marginal rates in France",  size(medium)) subtitle("{&rho} = 0.767") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_france);
twoway 	(tsline top_statutory2, lpattern(solid)) (tsline effective_p99_99,  lpattern(dash)) if country=="Netherlands", title("Top marginal rates in Netherlands",  size(medium)) subtitle("{&rho} = 0.914") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_netherlands);
twoway 	(tsline top_statutory2, lpattern(solid)) (tsline effective_p99_99,  lpattern(dash)) if country=="Sweden", title("Top marginal rates in Sweden",  size(medium)) subtitle("{&rho} = 0.837") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_sweden);
twoway 	(tsline top_statutory2, lpattern(solid)) (tsline effective_p99_99,  lpattern(dash)) if country=="United Kingdom", title("Top marginal rates in United Kingdom",  size(medium)) subtitle("{&rho} = 0.980") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_uk);
twoway 	(tsline top_statutory2, lpattern(solid)) (tsline irs_soi_top1,  lpattern(dash)) if country=="United States", title("Top marginal rates in United States",  size(medium)) subtitle("{&rho} = 0.864") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent) xtitle(Year) legend(label(1 "Statutory") label(2 "Effective")) ylab(0(20)100, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_04_us);

/**Figure 3.4. Statutory and Effective Income Tax Rates (page 62)**/
gr combine figure_3_04_canada figure_3_04_france figure_3_04_netherlands figure_3_04_sweden figure_3_04_uk figure_3_04_us, ycommon plotregion(fcolor(white)) graphregion(fcolor(white)) title("Statutory and effective rates",  size(medium));
graph save figure_3_04, replace;

graph drop _all;
restore;

/**
Make Figure 3.5
**/

preserve;
keep if timemarkeru~=.;

sort timemarkeru;
by timemarkeru: egen avg_top_incrate_n=mean(top_incrate_n);

/**Figure 3.5. Universal Male Suffrage and Top Rates of Income Taxation (page 66)**/
twoway (connected top_incrate_n timemarkeru if country=="United States", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="France", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="United Kingdom", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="Austria", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="Belgium", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="Canada", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="Denmark", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Italy", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Netherlands", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="New Zealand", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Spain", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Sweden", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Switzerland", lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkeru if country=="Finland", lcolor(gs11) msymbol(i))(connected top_incrate_n timemarkeru if country=="Japan", lcolor(gs11) msymbol(i))(connected avg_top_incrate_n timemarkeru, lwidth(vthick) lcolor(gs0) msymbol(i)) , ytitle(Percent) xtitle(Year Relative to Universal Male Suffrage) title(Universal Male Suffrage and Top Rate of Income Taxation)  graphregion(fcolor(white)) xline(0) legend(off);
graph save figure_3_05,replace;

restore;

/**
Make Figure 3.6
**/

preserve;

/**Figure 3.6. Suffrage Expansion and the UK Income Tax (page 69)**/
twoway (connected top_incrate_n year if ccode==200 & year>=1800 & year<=1925), ytitle(Percent) xtitle(Year) title(Top Marginal Income Tax Rate in United Kingdom) graphregion(fcolor(white)) legend(off) xline(1832) xline(1867)  xline(1884) xline(1918) text(45 1832 "Reform Act", place(c)) text(40 1832 "of 1832",place(c)) text(45 1867 "Reform Act",place(c)) text(40 1867 "of 1867", place(c)) text( 35 1884 "Third Reform",place(c)) text(30 1884 "Act", place(c)) text(45 1918 "Universal Male",place(c)) text(40 1918 "Suffrage", place(c)) xlabel(1800(25)1925);
graph save figure_3_06,replace;

restore;

/**
Make Figure 3.7
**/

preserve;

sort timemarkerp;
by timemarkerp: egen avg_top_incrate_n_p=mean(top_incrate_n);

/**Figure 3.7. Left Partisanship and Top Rates of Income Taxation (page 71)**/
twoway (connected top_incrate_n timemarkerp if country=="Australia" & year>=1905 & year<=1913, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Australia" & year>=1924 & year<=1932, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Australia" & year>=1936 & year<=1946, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Australia" & year>=1967 & year<=1975, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Australia" & year>=1978 & year<=1988, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Australia" & year>=2002 & year<=2012, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Austria" & year>=1913 & year<=1920, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Austria" & year>=1965 & year<=1975, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Austria" & year>=2002 & year<=2012, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Belgium" & year>=1940 & year<=1949, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Belgium" & year>=1950 & year<=1958, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Belgium" & year>=2005 & year<=2013, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Denmark" & year>=1919 & year<=1926, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Denmark" & year>=1988 & year<=1998, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Finland" & year>=1951 & year<=1959, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Finland" & year>=1961 & year<=1970, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Finland" & year>=1990 & year<=2000, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="France" & year>=1931 & year<=1938, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="France" & year>=1950 & year<=1957, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="France" & year>=1976 & year<=1986, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="France" & year>=1994 & year<=2002, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Germany" & year>=1913 & year<=1920, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Germany" & year>=1923 & year<=1930, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Germany" & year>=1964 & year<=1974, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Germany" & year>=1993 & year<=2003, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Italy" & year>=1978 & year<=1987, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Italy" & year>=1994 & year<=2001, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Italy" & year>=2002 & year<=2008, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Japan" & year>=1989 & year<=1996, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Netherlands" & year>=1943 & year<=1953, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Netherlands" & year>=1968 & year<=1977, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Netherlands" & year>=1989 & year<=1999, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="New Zealand" & year>=1930 & year<=1940, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="New Zealand" & year>=1952 & year<=1960, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="New Zealand" & year>=1967 & year<=1975, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="New Zealand" & year>=1979 & year<=1989, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="New Zealand" & year>=1994 & year<=2004, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Norway" & year>=1930 & year<=1940, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Norway" & year>=1941 & year<=1950, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Norway" & year>=1966 & year<=1976, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Norway" & year>=1982 & year<=1991, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Norway" & year>=2002 & year<=2010, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Spain" & year>=1926 & year<=1933, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Spain" & year>=1977 & year<=1987, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Spain" & year>=1999 & year<=2009, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Sweden" & year>=1927 & year<=1937, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="Sweden" & year>=1977 & year<=1987, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="United Kingdom" & year>=1925 & year<=1934, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="United Kingdom" & year>=1940 & year<=1950, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="United Kingdom" & year>=1959 & year<=1969, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="United Kingdom" & year>=1971 & year<=1979, lcolor(gs11) msymbol(i)) (connected top_incrate_n timemarkerp if country=="United Kingdom" & year>=1992 & year<=2003, lcolor(gs11) msymbol(i)) (connected avg_top_incrate_n_p timemarkerp, lwidth(vthick) lcolor(gs0) msymbol(i)), ytitle(Percent) xtitle(Year Relative to Left Party Control) title(Left Partisanship and Top Rate of Income Taxation) graphregion(fcolor(white)) xline(0) xlabel(-5(1)5) legend(off);
graph save figure_3_07,replace;

restore;

/**
Make Figure 3.8
**/

preserve;

drop if country=="Canada" & (year<1920 | year>2000);
drop if country=="France" & (year<1915 | year>2006);
drop if country=="Netherlands" & (year<1930 | year >1975);
drop if country=="Sweden" & (year<1903 | year>2010);
drop if country=="United Kingdom" & (year<1908 | year>1979);
drop if country=="United States" & (year<1913 | year >2010);

pwcorr top_incrate_n Top001incomeshare if country=="Canada";
pwcorr top_incrate_n Top001incomeshare if country=="France";
pwcorr top_incrate_n Top001incomeshare if country=="Netherlands";
pwcorr top_incrate_n Top001incomeshare if country=="Sweden";
pwcorr top_incrate_n Top001incomeshare if country=="United Kingdom";
pwcorr top_incrate_n Top001incomeshare if country=="United States";

twoway (line top_incrate_n year, lpattern(solid) yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="Canada" & year >= 1900, title("Rates and shares in Canada",  size(medium)) subtitle("{&rho} = -0.134") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_canada);
twoway (line top_incrate_n year, lpattern(solid)  yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="France" & year >= 1900, title("Rates and shares in France",  size(medium)) subtitle("{&rho} = -0.750") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_france);
twoway (line top_incrate_n year, lpattern(solid) yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="Netherlands" & year >= 1900, title("Rates and shares in the Netherlands", size(medium) ) subtitle("{&rho} = -0.856") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_netherlands);
twoway (line top_incrate_n year, lpattern(solid) yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="Sweden" & year >= 1900, title("Rates and shares in Sweden",  size(medium)) subtitle("{&rho} = -0.600") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_sweden);
twoway (line top_incrate_n year, lpattern(solid) yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="United Kingdom" & year >= 1900, title("Rates and shares in the UK", size(medium) ) subtitle("{&rho} = -0.896") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_uk);
twoway (line top_incrate_n year, lpattern(solid) yaxis(1)  yscale(range(0))) (line Top001incomeshare year,  lpattern(dash) yaxis(2)  ytitle("Income share",axis(2)))  if country=="United States" & year >= 1900, title("Rates and shares in the USA",  size(medium)) subtitle("{&rho} = -0.741") subtitle(, pos(12) ring(1) prefix nobexpand nobox span size(small)) ytitle(Percent, margin(0 4 0 0)) xtitle(Year) legend(label(1 "Top rate") label(2 "Income share")) ylab(0(20)100, nogrid) xlab(1900(25)2000, nogrid) legend(cols(2) size(small) symysize(3) span ) legend(region(lwidth(none))) plotregion(fcolor(white)) graphregion(fcolor(white)) name(figure_3_08_us);

/**Figure 3.8. Inequality and Top Rates of Income Taxation (page 75)**/
graph combine figure_3_08_canada figure_3_08_france figure_3_08_netherlands figure_3_08_sweden figure_3_08_uk figure_3_08_us, ycommon plotregion(fcolor(white)) graphregion(fcolor(white)) title("Statutory rates and top 0.01% income shares",  size(medium));
graph save figure_3_08,replace;

graph drop _all;
restore;

/**
Make Figure 3.9
**/

preserve;

bysort year: egen avg_top_incrate_n_wwi_mob=mean(top_incrate_n) if wwimassmob==1;
bysort year: egen med_top_incrate_n_wwi_mob=median(top_incrate_n) if wwimassmob==1;
bysort year: egen avg_top_incrate_nl_wwi_mob=mean(top_incrate_nl) if wwimassmob==1;
bysort year: egen med_top_incrate_nl_wwi_mob=median(top_incrate_nl) if wwimassmob==1;

bysort year: egen avg_top_incrate_n_wwi_nmob=mean(top_incrate_n) if wwimassmob==0;
bysort year: egen med_top_incrate_n_wwi_nmob=median(top_incrate_n) if wwimassmob==0;
bysort year: egen avg_top_incrate_nl_wwi_nmob=mean(top_incrate_nl) if wwimassmob==0;
bysort year: egen med_top_incrate_nl_wwi_nmob=median(top_incrate_nl) if wwimassmob==0;

gen temp=0;
gen temp2=0;

replace temp=0;
replace temp2=50;

/**Figure 3.9. World War I and Top Rates of Income Taxation (page 81)**/
twoway (rarea temp temp2 year if ccode==200 & year>=1914 & year<=1918, bcolor(gs14)) (connected avg_top_incrate_n_wwi_mob year if year>=1900 & year<=1930, lwidth(thick) lcolor(gs0) msymbol(i)) (connected avg_top_incrate_n_wwi_nmob year if year>=1900 & year<=1930, lpattern(dash) lwidth(thick) lcolor(gs0) msymbol(i)) , ytitle(Percent) xtitle(Year) title(World War I Mass Mobilization and Top Rate of Income Taxation)  graphregion(fcolor(white)) xlabel(1900(5)1930) legend( order(1 2 3) lab(1 "World War I") lab(2 "WWI Mobilization Countries") lab(3 "Non-Mobilization Countries"));
graph save figure_3_09,replace;

restore;

/**
Table 3.1. World War I and Progressive Income Taxation (page 82)
**/

display "Table 3.1: See Scheve and Stasavage (2010)";

/**
Make Figure 3.10
**/

bysort year: egen avg_top_incrate_n_wwi_mob_dem=mean(top_incrate_n) if (wwimassmob==1 & wwidemoc==1);
bysort year: egen avg_top_incrate_n_wwi_mob_ndem=mean(top_incrate_n) if (wwimassmob==1 & wwidemoc==0);

/**Figure 3.10. World War I and Top Rates by Political Regime Type (page 83)**/
twoway  (connected avg_top_incrate_n_wwi_mob_dem year if year>=1913 & year<=1919, lwidth(thick) lcolor(gs0) msymbol(i)) (connected avg_top_incrate_n_wwi_mob_ndem year if year>=1913 & year<=1919, lpattern(dash) lwidth(thick) lcolor(gs0) msymbol(i))  , ytitle(Percent) xtitle(Year) title(World War I Mass Mobilization and Top Rate of Income Taxation) subtitle(By Political Regime Type) graphregion(fcolor(white)) xlabel(1913(1)1919) legend( order(1 2) rows(2) lab(1 "WWI Democratic Mobilization Countries") lab(2 "WWI Non-Democratic Mobilization Countries"));
graph save figure_3_10,replace;

clear;

/**
Make Figure 3.11
**/

display "Figure 3.11: See Scheve and Stasavage (2010)";

use Scheve_Stasavage_TaxingtheRich_2016_Gallup.dta,replace;

twoway (line  EffTax1941class1 Income, lpattern(solid)) (line  EffTax1942Wclass1 Income, lpattern(dash)), ytitle(Effective Tax Rate (median response)) xtitle(Income (log scale)) xscale(log) xtick(1000 3000  5000 10000 50000 100000) xlabel(1000 3000 5000 10000 50000 100000) subtitle(Low SES Respondents) legend(order(1 "1941" 2 "1942")) graphregion(icolor(white) fcolor(white)) name(figure_3_11_low); 
twoway (line  EffTax1941class2 Income, lpattern(solid)) (line  EffTax1942Wclass2 Income, lpattern(dash)), ytitle(Effective Tax Rate (median response)) xtitle(Income (log scale)) xscale(log) xtick(1000 3000  5000 10000 50000 100000) xlabel(1000 3000 5000 10000 50000 100000) subtitle(Middle SES Respondents) legend(order(1 "1941" 2 "1942")) graphregion(icolor(white) fcolor(white)) name(figure_3_11_middle);
twoway (line  EffTax1941class3 Income, lpattern(solid)) (line  EffTax1942Wclass3 Income, lpattern(dash)), ytitle(Effective Tax Rate (median response)) xtitle(Income (log scale)) xscale(log) xtick(1000 3000  5000 10000 50000 100000) xlabel(1000 3000 5000 10000 50000 100000) subtitle(High SES Respondents) legend(order(1 "1941" 2 "1942")) graphregion(icolor(white) fcolor(white)) name(figure_3_11_high);

/**Figure 3.11. World War II and U.S. Opinion on Tax Progressivity (page 88)**/
graph combine figure_3_11_low figure_3_11_middle figure_3_11_high,  col(1) ycommon graphregion(margin(l=15 r=15)  fcolor(white) )  altshrink title("U.S. Public Opinion on Income Tax Progressivity") subtitle("Before and After Onset of World War II") xsize(6) ysize(7);
graph save figure_3_11.gph, replace;

graph drop _all;
clear;

/**
Make Figure 3.12
**/

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta,replace;
xtset ccode year;

preserve;
collapse  (mean) top_incrate_n revgdp_imf if independence==1 & year>=1800 & year<=2013, by(year);
summarize;

/**Figure 3.12. Average Top Income Tax Rates and Government Size, 1870-2010 (page 91)**/
twoway (line top_incrate_n year if year>=1870 & year<=2010, lwidth(medthick) lpattern(solid)) (line revgdp_imf year if year>=1870 & year<=2010, lwidth(medthick) lpattern(shortdash)), ytitle(Percent) xtitle(Year) title(Average Top Income Tax Rate and the Size of Government) subtitle(1870-2010) graphregion(fcolor(white)) legend(row(1) order(1 2) lab(1 "Income Tax Top Rate")  lab(2 "Revenue/GDP Percent"));
graph save figure_3_12,replace;

restore;

/**************
Chapter 4:
Taxing Inheritance
**************/

/**
Make Figure 4.1
**/

preserve;

collapse  (mean) topitaxrate2 if independence==1 & year>=1800 & year<=2013, by(year);
summarize;

/**Figure 4.1. Average Top Rates of Inheritance Taxation, 1800-2013 (page 101)**/
twoway (line topitaxrate2 year, lwidth(medthick) lpattern(solid)), ytitle(Percent) xtitle(Year) title(Average Top Rate of Inheritance Taxation) subtitle(1800-2013) graphregion(fcolor(white)) legend(off);
graph save figure_4_01,replace;

restore;

/**
Make Figure 4.2
**/

preserve;

keep if year==1914|year==1920;
keep country year ccode topitaxrate2 wealth_p99_00_2014 wwimassmob timemarkeru;

/*This series of code replaces missing observations with the closest available datapoint*/
replace wealth_p99_00_2014=33.98 if ccode==900; /*Australia (1915)*/
replace wealth_p99_00_2014=47 if year==1914 & ccode==390; /*Denmark (1915)*/
replace wealth_p99_00_2014=60.5 if year==1914 & ccode==220; /*France (1910)*/
replace wealth_p99_00_2014=50 if year==1920 & ccode==210; /*Netherlands (1919)*/
replace wealth_p99_00_2014=37.2 if ccode==385; /*Norway (1912)*/
replace wealth_p99_00_2014=53.8 if year==1914 & ccode==380; /*Sweden (1908)*/
replace wealth_p99_00_2014=42.3 if year==1914 & ccode==225; /*Switzerland (1915)*/
replace wealth_p99_00_2014=38.1 if year==1920 & ccode==225; /*Switzerland (1921)*/
replace wealth_p99_00_2014=69 if year==1914 & ccode==200; /*United Kingdom (1911)*/
replace wealth_p99_00_2014=60.9 if year==1920 & ccode==200; /*United Kingdom (1923)*/
replace wealth_p99_00_2014=36.7 if ccode==2; /*United States (1922)*/

gen countrysym=country;
replace countrysym="UK" if country=="United Kingdom";
replace countrysym="USA" if country=="United States";

twoway (scatter topitaxrate2 wealth_p99_00_2014 if year==1914 & wealth_p99_00_2014~=.,mlabel(countrysym) jitter(5) graphregion(fcolor(white)) title("1914") ytitle("Top Inheritance Tax Rate") xtitle("Top 1% Wealth Share",margin(0 0 0 4))), name(figure_4_02_1914); 
twoway (scatter topitaxrate2 wealth_p99_00_2014 if year==1920 & wealth_p99_00_2014~=.,mlabel(countrysym) jitter(5) graphregion(fcolor(white)) title("1920") ytitle("Top Inheritance Tax Rate") xtitle("Top 1% Wealth Share",margin(0 0 0 4))), name(figure_4_02_1920);

/**Figure 4.2. Wealth Inequality and Inheritance Taxes, 1914 and 1920 (page 105)**/
graph combine figure_4_02_1914 figure_4_02_1920, col(2) ycommon xcommon graphregion(fcolor(white) );
graph save figure_4_02,replace;

graph drop _all;
restore;

/**
Make Figure 4.3
**/

twoway (tsline topitaxrate2 if year>=1915 & year<=2010 & ccode==900 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1915 & year<=2010 & ccode==900 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in Australia") ytitle(Percent) xtitle(Year) xlabel(1910(20)2010) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_australia);
twoway (tsline topitaxrate2 if year>=1810 & year<=2010 & ccode==220 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1810 & year<=2010 & ccode==220 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in France") ytitle(Percent) xtitle(Year) xlabel(1810(20)2010) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_france);
twoway (tsline topitaxrate2 if year>=1894 & year<=2010 & ccode==210 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1894 & year<=2010 & ccode==210 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in Netherlands") ytitle(Percent) xtitle(Year) xlabel(1890(20)2010) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_netherlands);
twoway (tsline topitaxrate2 if year>=1800 & year<=2010 & ccode==380 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1800 & year<=2010 & ccode==380 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in Sweden") ytitle(Percent) xtitle(Year) xlabel(1800(20)2000) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_sweden);
twoway (tsline topitaxrate2 if year>=1810 & year<=2010 & ccode==200 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1810 & year<=2010 & ccode==200 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in the UK") ytitle(Percent) xtitle(Year) xlabel(1810(20)2010) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_uk);
twoway (tsline topitaxrate2 if year>=1860 & year<=2010 & ccode==2 & independence==1,lwidth(medthick) lpattern(solid)) (tsline wealth_p99_00_2014 if year>=1860 & year<=2010 & ccode==2 & independence==1,lwidth(medthick) lpattern(dash)), title("Rates and shares in the US") ytitle(Percent) xtitle(Year) xlabel(1860(20)2000) graphregion(fcolor(white)) legend(row(1) order(1 2)  lab(1 "Top Rate")  lab(2 "Top 1% Wealth Share")) fysize(100) name(figure_4_03_us);

/**Figure 4.3. Wealth Inequality and Inheritance Taxes over the Long Run (page 107)**/
graph combine figure_4_03_australia figure_4_03_france figure_4_03_netherlands figure_4_03_sweden figure_4_03_uk figure_4_03_us, ycommon graphregion(fcolor(white) )  altshrink xsize(6.5) ysize(8.5);
graph save figure_4_03,replace;

graph drop _all;
clear;

/**
Table 4.1. Marginal Inheritance Tax Rates by Size of Inheritance (page 112)
**/

display "Table 4.1: See Scheve and Stasavage (2012, 89) and the associated replication files";

/**************
Chapter 5:
Taxes on the Rich in Context
**************/

/**
Table 5.1. Total Burden of Taxation in the United Kingdom, 1903-1941 (page 122)
**/

display "Table 5.1: See Shirras and Rostas (1943, p. 24 and p. 58)";

/**************
Chapter 6:
The Conscription of Wealth
**************/

/**
Make Figure 6.1
**/

use Scheve_Stasavage_TaxingtheRich_2016_speechcoding.dta, replace;

mi import flongsep speechcoding_imputed, using(Scheve_Stasavage_TaxingtheRich_2016_speechcoding{1-10}) id(spnum) imputed(sptimp);
mi convert flong;

gen equaltreat=0;
replace equaltreat=1 if sptimp==1;
gen abiltopay=0;
replace abiltopay=1 if sptimp==2;
gen compensatory=0;
replace compensatory=1 if sptimp==3;
gen other=0;
replace other=1 if sptimp==4;

misum equaltreat abiltopay compensatory other if afterwar == 0;
gen equaltreat_mean = r(equaltreat_mean) if afterwar == 0;
gen abiltopay_mean = r(abiltopay_mean) if afterwar == 0;
gen compensatory_mean = r(compensatory_mean) if afterwar == 0;
gen other_mean = r(other_mean) if afterwar == 0;

misum equaltreat abiltopay compensatory other if afterwar == 1;
replace equaltreat_mean = r(equaltreat_mean) if afterwar == 1;
replace abiltopay_mean = r(abiltopay_mean) if afterwar == 1;
replace compensatory_mean = r(compensatory_mean) if afterwar == 1;
replace other_mean = r(other_mean) if afterwar == 1;

replace equaltreat_mean = equaltreat_mean*100;
replace abiltopay_mean = abiltopay_mean*100;
replace compensatory_mean = compensatory_mean*100;
replace other_mean = other_mean*100;

collapse *_mean, by(afterwar);

format *_mean %8.1f;

gen equaltreatf = (equaltreat_mean/(equaltreat_mean+abiltopay_mean+compensatory_mean))*100;
gen abiltopayf = (abiltopay_mean/(equaltreat_mean+abiltopay_mean+compensatory_mean))*100;
gen compensatoryf = (compensatory_mean/(equaltreat_mean+abiltopay_mean+compensatory_mean))*100;
format *f %8.1f;

label variable equaltreatf "Equal Treatment";
label variable abiltopayf "Ability to Pay";
label variable compensatoryf "Compensatory";

graph bar equaltreatf abiltopayf compensatoryf if afterwar == 0, b1title("Before World War I Begins") blabel(name, position(over)) ytitle("Percent") graphregion(fcolor(white)) legend(off) name(figure_6_01_beforewwi);
graph bar equaltreatf abiltopayf compensatoryf if afterwar == 1, b1title("After World War I Begins") blabel(name, position(over)) ytitle("Percent") graphregion(fcolor(white)) legend(off) name(figure_6_01_afterwwi);

/**Figure 6.1. Debating the Income Tax in the United Kingdom (page 143)**/
graph combine figure_6_01_beforewwi figure_6_01_afterwwi, col(2) ycommon graphregion(fcolor(white) ) altshrink xsize(7) ysize(4.5);
graph save figure_6_01,replace;

graph drop _all;
clear;

/**************
Chapter 7:
The Role of War Technology
**************/

/**
Make Figure 7.1
**/

display "Figure 7.1: See Onorato, Scheve, and Stasavage (2014)";

use "Scheve_Stasavage_TaxingtheRich_2016_OSSdata.dta", replace;
xtset ccode year;
sort ccode year;

gen period25yr = floor((year - 1600) / 25);
drop if waryear==0;
collapse mobil military1, by(period25yr);

/**Figure 7.1. Military Size and Mobilization, 1600-2000 (page 177)**/
twoway (connected military1 period25yr, yaxis(1) lpattern(solid)) (connected mobil period25yr,  yaxis(2) lpattern(dash)), xtitle(Years) xmlabel(0 "1600-25" 2 "1650-1675"   4 "1700-1725" 6 "1750-1775"  8 "1800-1825"  10 "1850-1875" 12 "1900-1925"  14 "1950-1975", format(%tqq)) xlab( 1 "1625-1650"   3 "1675-1700"  5 "1725-1750"  7 "1775-1800" 9 "1825-1850"  11 "1875-1900"  13 "1925-1950" 15 "1975-2000", labsize(vsmall) format(%tqCY) labgap(2)) ytitle(Military Size (thousands), size(medium) margin(0 3 0 0)) ytitle("Military Mobilization",  axis(2) margin(3 0 0 0)) graphregion(fcolor(white)) legend(label(1 "Military Size") label(2 "Military Mobilization")) legend(cols(2) size(small) symysize(3) span) plotregion(fcolor(white)) graphregion(fcolor(white));
graph save figure_7_01,replace;

clear;

/**************
Chapter 8:
Why Taxes on the Rich Declined
**************/

/**
Make Figure 8.1
**/

use "Scheve_Stasavage_TaxingtheRich_2016_equalsacrifice.dta", clear;
sort year;

gen temp=0;
gen temp2=1;

/**Figure 8.1. References to Equality of Sacrifice, 1844-2000 (page 202)**/
twoway  (rarea temp temp2 year if year>=1914 & year<=1918, yaxis(1) bcolor(gs14)) (rarea temp temp2 year if year>=1939 & year<=1945, yaxis(1) bcolor(gs14)) (line ngrams year if year>=1844 & year<2000, yaxis(1) lcolor(navy) lpattern(solid)) (line uk_ma year if year>=1844 & year<2000,  yaxis(2) lcolor(maroon) lpattern(longdash)) (line us_ma year if year>=1844 & year<2000,  yaxis(2) lcolor(green) lpattern(shortdash)), xtitle(Years) xlab(1844(20)2000) ytitle(Relative Frequency, size(medium) margin(0 4 0 0)) ytitle("Absolute Frequency",  axis(2) margin(4 0 0 0)) graphregion(fcolor(white)) legend(on order (1 3 4 5) label(1 "World War I and II") label(3 "Google Ngram Relative Frequency of{it: Equal Sacrifice}") label(4 "UK Parliament Absolute Frequency of{it: Equal Sacrifice}") label(5 "US Congress Absolute Frequency of{it: Equal Sacrifice}")) legend(cols(1) size(small) symysize(3) span) plotregion(fcolor(white)) graphregion(fcolor(white));
graph save figure_8_01,replace;

clear;

/**************
Chapter 9:
What Future for Taxing the Rich?
**************/

/**
Make Figure 9.1
**/

use "Scheve_Stasavage_TaxingtheRich_2016_BRMSsurveyexperiment.dta", replace;

/**Figure 9.1. Marginal Tax Rate Opinions, United States 2014 (page 212)**/
graph box ideal_rate_num_lt10 ideal_rate_num_10_35 ideal_rate_num_35_85 ideal_rate_num_85_175 ideal_rate_num_175_375 ideal_rate_num_gt375 [pw = weight],plotregion(fcolor(white)) graphregion(fcolor(white)) box(1,color(navy)) box(2,color(navy))box(3,color(navy))box(4,color(navy))box(5,color(navy))box(6,color(navy))  ytitle(Percent) ylabel(0(10)80) showyvars yvaroptions(relabel(1 "< $10k" 2 "$10k-35k"  3 "$35k-85k"  4 "$85-175k"  5 "$175k-375k" 6 ">$375k")) legend(off) noout note("");
graph save figure_9_01,replace;

clear;

/**********************************
Supplemental Material to Chapter 1
**********************************/

display "Information about the income and inheritance tax data presented in Figure 1.1. is described in appendix sections for Chapters 3 and 4.";

/**********************************
Supplemental Material to Chapter 2
**********************************/

use "Scheve_Stasavage_TaxingtheRich_2016_LSSsurveyexperiment.dta", replace;

sum weight;

gen age = 2014-birthyr;
gen age_cat = 1 if age >=18 & age < 35;
replace age_cat = 2 if age >=35 & age < 55;
replace age_cat = 3 if age >= 55;

gen edu_cat = 1 if educ == 1 | educ == 2;
replace edu_cat = 2 if educ == 3 | educ == 4;
replace edu_cat = 3 if educ == 5;
replace edu_cat = 4 if educ == 6;

/** Table A-1: Distribution of Socio-demographics in Spring 2014 YouGov Survey Sample and the Population **/
tab age_cat;
tab gender;
tab edu_cat;

tab age_cat [aweight=weight];
tab gender [aweight=weight];
tab edu_cat [aweight=weight];

clear;

/**********************************
Supplemental Material to Chapter 3
**********************************/

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
xtset ccode year;

drop if year < 1816;
drop if year > 2010;

/** Interpolate Values of Income Share and Wealth Share **/
by ccode: ipolate Top001incomeshare year if independence == 1, gen(Top001incomeshare_ipolate);
by ccode: ipolate Top1incomeshare year if independence == 1, gen(Top1incomeshare_ipolate);
by ccode: ipolate wealth_p99_00_2014 year if independence == 1, gen(wealth_p99_00_2014_ipolate);

xtset ccode year;

/** Table A-2: Descriptive Statistics, 1816-2010: Annual Data **/
sum top_incrate_n top_incrate_nl himobpopyear2p himobpopyearp unisuffrage competitive_elections noupper directelec electorate* left_executive Top1incomeshare Top001incomeshare majoritarian1 any_cris infl_cris bank_cris debt_cris_dom debt_cris_ext stock_crash currency_cris Neightop_incrate_n trade_openness rgdppc occupied;

/** Table A-28: Descriptive Statistics, 1900-2010: Annual Data **/
sum topitaxrate2 wealth_p99_00_2014 if country != "Spain" & year >= 1900;

/** Create 5 year panel data 1816-2010 **/
collapse  (first) year ccode *trend (mean) top_incrate_n top_incrate_nl wealth_p99_00_2014 wealth_p99_00_2014_ipolate revgdp_imf infl_cris debt_cris_dom debt_cris_ext bank_cris stock_crash currency_cris rgdppc Top001incomeshare Top1incomeshare Top001incomeshare_ipolate Top1incomeshare_ipolate independence competitive_elections unisuffrage directelec noupper electorate25 electorate50 electorate75 majoritarian1 left_executive himobpopyear2p himobpopyearp topitaxrate2 revgdp_imf_ip Neightop_incrate_n any_cris capital pop rgdp growth recession effective_p99_99 irs_soi_top1 trade_openness occupied (first) firsttop_incrate_n=top_incrate_n firsttop_incrate_nl=top_incrate_nl firsttopitaxrate2=topitaxrate2 firstrevgdp_imf=revgdp_imf firstwealth_p99_00_2014_ipolate=wealth_p99_00_2014_ipolate firstTop001incomeshare_ipolate=Top001incomeshare_ipolate firstTop1incomeshare_ipolate=Top1incomeshare_ipolate firstleft_executive=left_executive firstmajoritarian1=majoritarian1 firstNeightop_incrate_n=Neightop_incrate_n firstwealth_p99_00_2014=wealth_p99_00_2014 firstcompetitive_elections=competitive_elections firstTop001incomeshare=Top001incomeshare firstTop1incomeshare=Top1incomeshare firstrgdp=rgdp firstpop=pop firstoccupied=occupied if independence==1 & year>=1816 & year<=2010, by(country hdecadec);
xtset ccode hdecadec;

/** Table A-3: War Mobilization, Democracy, and Income Taxation, 1816-2010: Universal Male Suffrage Measure of Democracy **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-4: War Mobilization, Democracy, and Income Taxation, 1816-2010: Competitive Elections Measure of Democracy **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-5: War Mobilization, Democracy, and Income Taxation, 1816-2010: Direct Elections Measure of Democracy **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.directelec i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.directelec l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.directelec l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.directelec i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.directelec l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.directelec l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-6: War Mobilization, Democracy, and Income Taxation, 1816-2010: Electorate Size Measure of Democracy **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 i.ccode i.hdecadec,robust cluster(ccode);
testparm l1.electorate25 l1.electorate50 l1.electorate75;
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
testparm l1.electorate25 l1.electorate50 l1.electorate75;
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
testparm l1.electorate25 l1.electorate50 l1.electorate75;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 i.hdecadec;
testparm l1.electorate25 l1.electorate50 l1.electorate75;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 l1.left_executive l1.rgdppc i.hdecadec;
testparm l1.electorate25 l1.electorate50 l1.electorate75;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.electorate25 l1.electorate50 l1.electorate75 l1.left_executive l1.rgdppc i.hdecadec *trend;
testparm l1.electorate25 l1.electorate50 l1.electorate75;

/** Table A-7: War Mobilization, Democracy, and Income Taxation, 1816-2010: No Upper Measure of Democracy **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.noupper i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.noupper l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.noupper l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.noupper i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.noupper l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.noupper l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-8: War Mobilization, Democracy, and Income Taxation, 1816-2010: Lagged Dependent Variable and Fixed Effects Specifications **/
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage i.ccode i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections i.ccode i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend;

/** Table A-9: War Mobilization, Democracy, and Income Taxation, 1816-2010: Interactions between War Mobilization and Democracy and Partisanship Measures **/
xi: reg  firsttop_incrate_n c.l1.himobpopyear2p##c.l1.competitive_elections i.ccode i.hdecadec,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n c.l1.himobpopyear2p##c.l1.competitive_elections i.hdecadec;
xi: reg  firsttop_incrate_n c.l1.himobpopyear2p##c.l1.left_executive i.ccode i.hdecadec,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n c.l1.himobpopyear2p##c.l1.left_executive i.hdecadec;

/** Table A-10: War Mobilization, Democracy, and Income Taxation-Local and National, 1816-2010: Universal Male Suffrage Measure of Democracy **/
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage i.hdecadec;
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-11: War Mobilization, Democracy, and Income Taxation-Local and National, 1816-2010: Competitive Elections Measure of Democracy **/
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections i.hdecadec;
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_nl l1.firsttop_incrate_nl l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-12: War Mobilization, Democracy, and Income Taxation, 1816-2010: Universal Male Suffrage Measure of Democracy and 5% Threshold for War Mobilization **/
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.unisuffrage i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.unisuffrage i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-13: War Mobilization, Democracy, and Income Taxation, 1816-2010: Competitive Elections Measure of Democracy and 5% Threshold for War Mobilization **/
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.competitive_elections i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyearp l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.competitive_elections i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyearp l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-14: War Mobilization, Democracy, and Income Taxation, 1816-2010: Universal Male Suffrage Measure of Democracy and Sample Restricted to Country-Periods without Foreign Occupation **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage i.ccode i.hdecadec if occupied == 0,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec if occupied == 0,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend if occupied == 0,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage i.hdecadec if occupied == 0;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec if occupied == 0;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend if occupied == 0;

/** Table A-15: War Mobilization, Democracy, and Income Taxation, 1816-2010: Competitive Elections Measure of Democracy and Sample Restricted to Country-Periods without Foreign Occupation **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections i.ccode i.hdecadec if occupied == 0,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec if occupied == 0,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend if occupied == 0,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections i.hdecadec if occupied == 0;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec if occupied == 0;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.competitive_elections l1.left_executive l1.rgdppc i.hdecadec *trend if occupied == 0;

/** Table A-16: War Mobilization, Electoral Institutions, and Income Taxation, 1816-2010 **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-17: War Mobilization, Electoral Institutions, and Income Taxation, 1816-2010: Sample Restricted to Democratic Country-Periods **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 i.ccode i.hdecadec if competitive_elections == 1,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.left_executive l1.rgdppc i.ccode i.hdecadec if competitive_elections == 1,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend if competitive_elections == 1,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 i.hdecadec if competitive_elections == 1;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.left_executive l1.rgdppc i.hdecadec if competitive_elections == 1;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.majoritarian1 l1.left_executive l1.rgdppc i.hdecadec *trend if competitive_elections == 1;

/** Table A-18: War Mobilization, Economic Crises, and Income Taxation, 1816-2010: Composite Measure of Crises **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.any_cris i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.any_cris l1.unisuffrage l1.left_executive l1.rgdppc  i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.any_cris l1.unisuffrage l1.left_executive l1.rgdppc  i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.any_cris i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.any_cris l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.any_cris l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-19: War Mobilization, Economic Crises, and Income Taxation, 1816-2010: Separate Measures of Crises **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash l1.unisuffrage l1.left_executive l1.rgdppc  i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash l1.unisuffrage l1.left_executive l1.rgdppc  i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p l1.debt_cris_dom l1.debt_cris_ext l1.bank_cris l1.infl_cris l1.currency_cris l1.stock_crash l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-20: War Mobilization, Economic Crises, and Income Taxation, 1816-2010: Estimating a Structural Break in Effect of Crises at 1970 **/
gen post_1970 = 0;
replace post_1970 = 1 if year > 1970;

xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 l1.unisuffrage  l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 l1.unisuffrage  l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.any_cris c.l1.any_cris#i.l1.post_1970 l1.unisuffrage  l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-21: War Mobilization, Policy Diffusion, and Income Taxation, 1816-2010 **/
xi: reg  firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p i.hdecadec;
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.firstNeightop_incrate_n l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-22: War Mobilization, Trade Openness, and Income Taxation, 1871-2010 **/
xi: reg  firsttop_incrate_n l.trade_openness l.himobpopyear2p i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l.trade_openness l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l.trade_openness l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.trade_openness l.himobpopyear2p i.hdecadec;
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.trade_openness l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l.firsttop_incrate_n l.trade_openness l.himobpopyear2p l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-23: War Mobilization, Inequality, and Income Taxation, 1900-2010: Income Share of Top 1% Measure of Inequality **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend if year >= 1900,robust cluster(ccode);
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate i.hdecadec if year >= 1900;
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec if year >= 1900;
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top1incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend if year >= 1900;

/** Table A-24: War Mobilization, Inequality, and Income Taxation, 1900-2010: Income Share of Top 0.01% Measure of Inequality **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend if year >= 1900,robust cluster(ccode);
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate i.hdecadec if year >= 1900;
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec if year >= 1900;
xi: xtpcse firsttop_incrate_n l.firsttop_incrate_n l1.himobpopyear2p l1.Top001incomeshare_ipolate l1.unisuffrage l1.left_executive l1.rgdppc i.hdecadec *trend if year >= 1900;

/** Table A-25: War Mobilization, Inequality, Institutions, and Income Taxation, 1900-2010 **/
xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.unisuffrage i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.unisuffrage i.hdecadec if year >= 1900;
xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.competitive_elections i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.competitive_elections i.hdecadec if year >= 1900;
xi: reg  firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.majoritarian1 i.ccode i.hdecadec if year >= 1900 & competitive_elections == 1,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.himobpopyear2p c.l1.Top1incomeshare_ipolate##c.l1.majoritarian1 i.hdecadec if year >= 1900 & competitive_elections == 1;

/** Table A-26: Granger Causality Analysis of Income Inequality and Income Taxation, 1900-2010: Income Share of Top 1% Measure of Inequality **/
xi: reg  top_incrate_n l1.top_incrate_n l1.Top1incomeshare_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  top_incrate_n l1.top_incrate_n l1.Top1incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  Top1incomeshare_ipolate l1.top_incrate_n l1.Top1incomeshare_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  Top1incomeshare_ipolate l1.top_incrate_n l1.Top1incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);

/** Table A-27: Granger Causality Analysis of Income Inequality and Income Taxation, 1900-2010: Income Share of Top 0.01% Measure of Inequality **/
xi: reg  top_incrate_n l1.top_incrate_n l1.Top001incomeshare_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  top_incrate_n l1.top_incrate_n l1.Top001incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  Top001incomeshare_ipolate l1.top_incrate_n l1.Top001incomeshare_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  Top001incomeshare_ipolate l1.top_incrate_n l1.Top001incomeshare_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);

/**********************************
Supplemental Material to Chapter 4
**********************************/

/** Table A-29: Granger Causality Analysis of Wealth Inequality and Inheritance Taxation, 1900-2010 **/
xi: reg  topitaxrate2 l1.topitaxrate2 l1.wealth_p99_00_2014_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  topitaxrate2 l1.topitaxrate2 l1.wealth_p99_00_2014_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  wealth_p99_00_2014_ipolate l1.topitaxrate2 l1.wealth_p99_00_2014_ipolate i.ccode c.hdecadec if year >= 1900,robust cluster(ccode);
xi: reg  wealth_p99_00_2014_ipolate l1.topitaxrate2 l1.wealth_p99_00_2014_ipolate i.ccode i.hdecadec if year >= 1900,robust cluster(ccode);

clear;

/**********************************
Supplemental Material to Chapter 5
**********************************/

use Scheve_Stasavage_TaxingtheRich_2016_Lindert.dta, replace;
xtset ccode decade;

/** Table A-30: Descriptive Statistics, 1880-1930 **/
sum spending_sum l.himobpopyear2p l.unisuffrage l.competitive_elections if spending_sum != .;

/** Table A-31: War Mobilization, Democracy, and Public Spending, 1880-1930 **/
xi: reg  spending_sum l.himobpopyear2p l.unisuffrage i.ccode i.decade,robust cluster(ccode);
xi: reg  spending_sum l.himobpopyear2p l.competitive_elections i.ccode i.decade,robust cluster(ccode);

clear;

/**********************************
Supplemental Material to Chapter 7
**********************************/

display "All data and statistical analyses discussed in this chapter can be found in Onorato, Scheve, and Stasavage (2014) and the online appendix and data archive for that article.";

/**********************************
Supplemental Material to Chapter 8
**********************************/

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
drop if year < 1945;
drop if year > 2010;

xtset ccode year;

gen cut_top_incrate_n = .;
replace cut_top_incrate_n = 0 if top_incrate_n >= l.top_incrate_n & top_incrate_n != . & l.top_incrate_n != .;
replace cut_top_incrate_n = 1 if top_incrate_n < l.top_incrate_n & top_incrate_n != . & l.top_incrate_n != .;

bysort year: egen annualmean_capital = mean(capital);
gen high_capital = 0 if annualmean_capital != .;
replace high_capital = 1 if capital > annualmean_capital & capital != .;

xtset ccode year;

gen rgdp_billions = rgdp/1000000000;

/** Table A-32: Descriptive Statistice, 1950-2010: Annual Data **/
sum top_incrate_n cut_top_incrate_n d.top_incrate_n topitaxrate2 effective_p99_99 recession growth d.growth any_cris capital rgdp_billions pop left_exec rgdppc if year >= 1950 & year <= 2010 & independence == 1 & top_incrate_n != .;

/** Table A-33: Recession History and Top Income Tax Rates, 1974-2010 **/
sum cut_top_incrate_n if recession == 0 & l1.recession == 0 & l2.recession == 0 & year > 1973 & independence == 1;
sum cut_top_incrate_n if recession == 1 & year > 1973 & independence == 1;
sum cut_top_incrate_n if recession == 1 & l1.recession == 1 & year > 1973 & independence == 1;
sum cut_top_incrate_n if recession == 1 & l1.recession == 1 & l2.recession == 1 & year > 1973 & independence == 1;

sum d.top_incrate_n if recession == 0 & l1.recession == 0 & l2.recession == 0 & year > 1973 & independence == 1;
sum d.top_incrate_n if recession == 1 & year > 1973 & independence == 1;
sum d.top_incrate_n if recession == 1 & l1.recession == 1 & year > 1973 & independence == 1;
sum d.top_incrate_n if recession == 1 & l1.recession == 1 & l2.recession == 1 & year > 1973 & independence == 1;

gen top_incrate_n1973 = .;
replace top_incrate_n1973 = 67 if country == "Australia";
replace top_incrate_n1973 = 62 if country == "Austria";
replace top_incrate_n1973 = 55 if country == "Belgium";
replace top_incrate_n1973 = 47 if country == "Canada";
replace top_incrate_n1973 = 43.7 if country == "Denmark";
replace top_incrate_n1973 = 53 if country == "Finland";
replace top_incrate_n1973 = 60 if country == "France";
replace top_incrate_n1973 = 53 if country == "Germany";
replace top_incrate_n1973 = 80 if country == "Ireland";
replace top_incrate_n1973 = 72 if country == "Italy";
replace top_incrate_n1973 = 75 if country == "Japan";
replace top_incrate_n1973 = 71 if country == "Netherlands";
replace top_incrate_n1973 = 46.3 if country == "New Zealand";
replace top_incrate_n1973 = 50 if country == "Norway";
replace top_incrate_n1973 = 48 if country == "South Korea";
replace top_incrate_n1973 = 61.4 if country == "Spain";
replace top_incrate_n1973 = 54 if country == "Sweden";
replace top_incrate_n1973 = 9.5 if country == "Switzerland";
replace top_incrate_n1973 = 75 if country == "United Kingdom";
replace top_incrate_n1973 = 70 if country == "United States";

gen top_incrate_n1983 = .;
replace top_incrate_n1983 = 60 if country == "Australia";
replace top_incrate_n1983 = 62 if country == "Austria";
replace top_incrate_n1983 = 67.5 if country == "Belgium";
replace top_incrate_n1983 = 34 if country == "Canada";
replace top_incrate_n1983 = 44.1 if country == "Denmark";
replace top_incrate_n1983 = 51 if country == "Finland";
replace top_incrate_n1983 = 65 if country == "France";
replace top_incrate_n1983 = 56 if country == "Germany";
replace top_incrate_n1983 = 65 if country == "Ireland";
replace top_incrate_n1983 = 72 if country == "Italy";
replace top_incrate_n1983 = 75 if country == "Japan";
replace top_incrate_n1983 = 72 if country == "Netherlands";
replace top_incrate_n1983 = 63 if country == "New Zealand";
replace top_incrate_n1983 = 41 if country == "Norway";
replace top_incrate_n1983 = 60 if country == "South Korea";
replace top_incrate_n1983 = 65 if country == "Spain";
replace top_incrate_n1983 = 54 if country == "Sweden";
replace top_incrate_n1983 = 11.5 if country == "Switzerland";
replace top_incrate_n1983 = 60 if country == "United Kingdom";
replace top_incrate_n1983 = 50 if country == "United States";

gen difftop_incrate_n1973_1983 = top_incrate_n1983 - top_incrate_n1973;

gen period = .;
replace period = 1 if year >= 1964 & year <= 1973;
replace period = 2 if year >= 1974 & year <= 1983;
drop if period == .;

collapse growth top_incrate_n difftop_incrate_n1973_1983 ccode independence, by(country period);

xtset ccode period;
pwcorr difftop_incrate_n1973_1983 d.growth if period == 2 & independence == 1, sig;
set scheme s2mono;

/** Figure A-1: Growth and Income Taxation **/
twoway scatter difftop_incrate_n1973_1983 d.growth if period == 2 & independence == 1, name(d_top_incrate_n) subtitle("{&rho} = -0.382", pos(12) ring(1) prefix nobexpand nobox span size(small)) xtitle("{&Delta} Growth Rate" "1964-1973 to 1974-1983", size(small)) /*xlab(-0.06(0.01)0, nogrid labsize(vsmall))*/ ytitle("{&Delta} Top Income Tax Rate" "1973 to 1983", size(small)) /*ylab(-20(10)10, nogrid labsize(vsmall))*/ mlabel(country) plotregion(fcolor(white)) graphregion(fcolor(white));
graph save figure_appendix_1,replace;
graph export figure_appendix_1.png, replace;

graph drop _all;

clear;

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
drop if year < 1945 | year > 2010;
xtset ccode year;

bysort year: egen annualmean_capital = mean(capital);
gen high_capital = 0 if annualmean_capital != .;
replace high_capital = 1 if capital >= annualmean_capital;

/** Table A-34: Mean Top Income Tax Rate by Year and Relative Capital Opnness, 1950-2010: Mean Level of Capital Openness Threshold **/
bysort high_capital: sum top_incrate_n if year == 1950 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 1960 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 1970 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 1980 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 1990 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 2000 & independence == 1;
bysort high_capital: sum top_incrate_n if year == 2010 & independence == 1;

clear;

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
xtset ccode year;

/** Interpolate Values of Effective Tax Rates **/
by ccode: ipolate effective_p99_99 year if independence == 1, gen(effective_p99_99_ipolate);
drop if year < 1816 | year > 2010;
xtset ccode year;

/** Create 5 year panel data 1816-2010 **/
collapse  (first) year ccode *trend (mean) top_incrate_n rgdppc independence competitive_elections unisuffrage left_executive himobpopyear2p capital pop rgdp growth recession effective_p99_99 effective_p99_99_ipolate (first) firsttop_incrate_n=top_incrate_n firsttopitaxrate2=topitaxrate2 firsteffective_p99_99=effective_p99_99 firsteffective_p99_99_ipolate=effective_p99_99_ipolate if independence==1 & year>=1816 & year<=2010, by(country hdecadec);
xtset ccode hdecadec;

/** Table A-35: Capital Openness and Income Taxation, 1950-2010 **/
xi: reg  firsttop_incrate_n l1.capital i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttop_incrate_n l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.capital i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.capital l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttop_incrate_n l1.firsttop_incrate_n l1.capital l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-36: Capital Openness and Inheritance Taxation, 1950-2010 **/
xi: reg  firsttopitaxrate2 l1.capital i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttopitaxrate2 l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsttopitaxrate2 l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsttopitaxrate2 l1.firsttopitaxrate2 l1.capital i.hdecadec;
xi: xtpcse  firsttopitaxrate2 l1.firsttopitaxrate2 l1.capital l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsttopitaxrate2 l1.firsttopitaxrate2 l1.capital l1.left_executive l1.rgdppc i.hdecadec *trend;

/** Table A-37: Capital Openness and Effective Income Taxation, 1950-2010 **/
xi: reg  firsteffective_p99_99_ipolate l1.capital i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsteffective_p99_99_ipolate l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec,robust cluster(ccode);
xi: reg  firsteffective_p99_99_ipolate l1.capital l1.left_executive l1.rgdppc i.ccode i.hdecadec *trend,robust cluster(ccode);
xi: xtpcse  firsteffective_p99_99_ipolate l1.firsteffective_p99_99_ipolate l1.capital i.hdecadec;
xi: xtpcse  firsteffective_p99_99_ipolate l1.firsteffective_p99_99_ipolate l1.capital l1.left_executive l1.rgdppc i.hdecadec;
xi: xtpcse  firsteffective_p99_99_ipolate l1.firsteffective_p99_99_ipolate l1.capital l1.left_executive l1.rgdppc i.hdecadec *trend;

clear;

use Scheve_Stasavage_TaxingtheRich_2016_annual.dta, replace;
xtset ccode year;
drop if year < 1816;
drop if year > 2010;

/** Table A-38: Correlation Between Relative Size and Income Taxation, 1950-2010 **/
cor top_incrate_n rgdp if year == 1950;
cor top_incrate_n rgdp if year == 1960;
cor top_incrate_n rgdp if year == 1970;
cor top_incrate_n rgdp if year == 1980;
cor top_incrate_n rgdp if year == 1990;
cor top_incrate_n rgdp if year == 2000;
cor top_incrate_n rgdp if year == 2010;

cor top_incrate_n pop if year == 1950;
cor top_incrate_n pop if year == 1960;
cor top_incrate_n pop if year == 1970;
cor top_incrate_n pop if year == 1980;
cor top_incrate_n pop if year == 1990;
cor top_incrate_n pop if year == 2000;
cor top_incrate_n pop if year == 2010;

/** Create 5 year panel data 1816-2010 **/
collapse  (first) year ccode *trend (mean) top_incrate_n rgdppc independence competitive_elections unisuffrage left_executive himobpopyear2p capital pop rgdp growth recession effective_p99_99 (first) firsttop_incrate_n=top_incrate_n firsttopitaxrate2=topitaxrate2 firsteffective_p99_99=effective_p99_99 if independence==1 & year>=1816 & year<=2010, by(country hdecadec);
xtset ccode hdecadec;

/** Table A-39: Pesaran Test of Cross-Sectional Dependence, 1950-2010 **/
xi: xtreg firsttop_incrate_n l1.capital i.ccode i.hdecadec if independence == 1 & year >= 1950 & year <= 2010,robust cluster(ccode);
xtcsd, pesaran abs;

xi: xtreg firsttop_incrate_n l1.capital i.ccode i.hdecadec if independence == 1 & year >= 1950 & year <= 1979,robust cluster(ccode);
capture noisily xtcsd, pesaran abs;

xi: xtreg firsttop_incrate_n l1.capital i.ccode i.hdecadec if independence == 1 & year >= 1980 & year <= 2010,robust cluster(ccode);
capture noisily xtcsd, pesaran abs;

clear;

/**********************************
Supplemental Material to Chapter 9
**********************************/

use "Scheve_Stasavage_TaxingtheRich_2016_BRMSsurveyexperiment.dta", replace;

gen age_cat = 1 if age >=18 & age < 35;
replace age_cat = 2 if age >=35 & age < 55;
replace age_cat = 3 if age >= 55;

gen edu_cat = 1 if educ == 1 | educ == 2;
replace edu_cat = 2 if educ == 3 | educ == 4;
replace edu_cat = 3 if educ == 5;
replace edu_cat = 4 if educ == 6;

/** Table A-40: Distribution of Socio-demographics in Summer 2014 YouGov Survey Sample and the Population **/
tab age_cat;
tab gender;
tab edu_cat;

tab age_cat [aweight=weight];
tab gender [aweight=weight];
tab edu_cat [aweight=weight];

clear;
log close;
